**Example 1: 获取临时密钥**

获取临时密钥

Input: 

```
tccli rum DescribeReleaseFileSign --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "SecretKey": "dahfldaflndfdfdsf",
        "SecretID": "asdkadalsdlsafk",
        "SessionToken": "fdslkfjdkjfldsjfdfdf",
        "StartTime": 1232132132,
        "ExpiredTime": 123212143434,
        "RequestId": "65a8fec7-2b39-4b11-893f-3715279d235f"
    }
}
```

